@@ -333,7 +333,7 @@ class ReleditEntityFormHandler(ReleditFormHandler):
         return self._cw.vreg['formrenderers'].select(
             self._form_renderer_id, self._cw, entity=entity,
             display_label=True, table_class='attributeForm',
-            display_help=False, button_bar_class='buttonbar',
+            button_bar_class='buttonbar',
             display_progress_div=False)
 
     def _build_form(self, entity, divid, reload, action, extradata=None, **formargs):
@@ -452,7 +452,7 @@ class ReleditRelationFormHandler(ReleditFormHandler):
             self._form_renderer_id, self._cw, entity=related_entity,
             display_label=display_label,
             table_class='attributeForm' if display_label else '',
-            display_help=False, button_bar_class='buttonbar',
+            button_bar_class='buttonbar',
             display_progress_div=False)
 
     def _build_form(self, entity, rschema, role, divid, reload, action,
